package de.fahsel.dewis;

import java.util.HashMap;
import java.util.Map;

/**
 * Diese Klasse repräsentiert einen Verband und dient in der Haupsache dazu, dessen Spielerliste abzufragen.
 * 
 * @author Peter Fahsel
 */
public class Association extends LoadableOrganisation
{
	private static final Map<String, Association> instances = new HashMap<>();
	
	private static final String LOAD_URL = "http://www.schachbund.de/php/dewis/verband.php?zps=$$zps$$&format=csv";
	
	protected Association(String zps)
	{
		super(zps);
	}

	protected static void clearInstances()
	{
		synchronized(instances)
		{
			instances.clear();
		}
	}
	
	protected static Association getInstance(String zps)
	{
		synchronized(instances)
		{
			Association instance = instances.get(zps);
			if (instance == null)
			{
				instance = new Association(zps);
				instances.put(zps, instance);
			}
			return instance;
		}
	}
	
	@Override
	protected String getLoadUrl()
	{
		return LOAD_URL;
	}
	
}
