package de.fahsel.dewis;

import java.util.HashMap;
import java.util.Map;

/**
 * Diese Klasse repräsentiert einen Verein und dient in der Haupsache dazu, dessen Spielerliste abzufragen.
 * 
 * @author Peter Fahsel
 */
public class Club extends LoadableOrganisation
{
	private static final Map<String, Club> instances = new HashMap<>();
	
	private static final String LOAD_URL = "http://www.schachbund.de/php/dewis/verein.php?zps=$$zps$$&format=csv";
	
	protected Club(String zps)
	{
		super(zps);
	}
	
	protected static void clearInstances()
	{
		synchronized(instances)
		{
			instances.clear();
		}
	}
	
	protected static Club getInstance(String zps)
	{
		synchronized(instances)
		{
			Club instance = instances.get(zps);
			if (instance == null)
			{
				instance = new Club(zps);
				instances.put(zps, instance);
			}
			return instance;
		}
	}
	
	@Override
	protected String getLoadUrl()
	{
		return LOAD_URL;
	}

}
