package de.fahsel.dewis;

/**
 * Diese Klasse repräsentiert eine Vereinsmitgliedschaft. Auf Mitgliedschaften 
 * kann mit den entsprechenden Methoden an der {@link Player}-Klasse zugegriffen werden.
 * 
 * @see Player#getClubMemberships()
 * @see Player#getActiveClubMembership()
 * @see Player#getPassiveClubMemberships()
 * @see Player#getClubMembershipByZps(String)
 * 
 * @author Peter Fahsel
 *
 */
public class ClubMembership extends AbstractMembership
{
	private String  			 status;
	private Integer 	         zps;
	
	protected ClubMembership(Club club, String status, String zps)
	{
		this(club, status, Integer.parseInt(zps));
	}

	protected ClubMembership(Club club, String status, Integer zps)
	{
		super(club);
		this.status = status;
		this.zps    = zps;
	}

	/**
	 * @return Der Verein für den die Mitgliedschaft besteht
	 */
	public Club getClub()
	{
		return (Club) getOrganisation();
	}

	/**
	 * @return Der Status der Mitgliedschaft
	 */
	public String getStatus()
	{
		return status;
	}

	/**
	 * @return Die Mitgliedsnummer bzw. der 2. Teil der Spieler-ZPS
	 */
	public Integer getZps()
	{
		return zps;
	}
}
