package de.fahsel.dewis;

/**
 * Diese Klasse repräsentiert eine Turnierteilname und wird von der {@link Player}-Klasse
 * zur Verfügung gestellt
 * 
 * @see Player#getTournaments()
 * 
 * @author Peter Fahsel
 *
 */
public class Tournament
{
	private String  code;
	private String  name;
	private Integer oldDwz;
	private Integer oldDwzIndex;
	private Float   points;
	private Integer matches;
	private Integer unrated;
	private Float   experienceValue;
	private Integer opponentDwz;
	private Integer coefficient;
	private Integer newDwz;
	private Integer newDwzIndex;
	private Integer performance;
	
	/**
	 * @return Code des Turniers
	 */
	public String getCode()
	{
		return code;
	}
	
	protected void setCode(String code)
	{
		this.code = code;
	}
	
	/**
	 * @return Name des Turniers
	 */
	public String getName()
	{
		return name;
	}
	
	protected void setName(String name)
	{
		this.name = name;
	}
	
	/**
	 * @return Alte DWZ
	 */
	public Integer getOldDwz()
	{
		return oldDwz;
	}
	
	protected void setOldDwz(Integer oldDwz)
	{
		this.oldDwz = oldDwz;
	}
	
	protected void setOldDwz(String oldDwz)
	{
		try
		{
			this.oldDwz = Integer.parseInt(oldDwz);
		}
		catch (Exception e)
		{
			this.oldDwz = null;
		}
	}
	
	/**
	 * @return Alter DWZ Index
	 */
	public Integer getOldDwzIndex()
	{
		return oldDwzIndex;
	}
	
	protected void setOldDwzIndex(Integer oldDwzIndex)
	{
		this.oldDwzIndex = oldDwzIndex;
	}
	
	protected void setOldDwzIndex(String oldDwzIndex)
	{
		try
		{
			this.oldDwzIndex = Integer.parseInt(oldDwzIndex);
		}
		catch (Exception e)
		{
			this.oldDwzIndex = null;
		}
	}
	
	/**
	 * @return Punkte
	 */
	public Float getPoints()
	{
		return points;
	}
	
	protected void setPoints(Float points)
	{
		this.points = points;
	}
	
	protected void setPoints(String points)
	{
		try
		{
			this.points = Float.parseFloat(points);
		}
		catch (Exception e)
		{
			this.points = null;
		}
	}
	
	/**
	 * @return Anzahl Spiele
	 */
	public Integer getMatches()
	{
		return matches;
	}
	
	protected void setMatches(Integer matches)
	{
		this.matches = matches;
	}
	
	protected void setMatches(String matches)
	{
		try
		{
			this.matches = Integer.parseInt(matches);
		}
		catch (Exception e)
		{
			this.matches = null;
		}
	}
	
	/**
	 * @return Anzahl nicht gewerteter Spiele
	 */
	public Integer getUnrated()
	{
		return unrated;
	}
	
	protected void setUnrated(Integer unrated)
	{
		this.unrated = unrated;
	}
	
	protected void setUnrated(String unrated)
	{
		try
		{
			this.unrated = Integer.parseInt(unrated);
		}
		catch (Exception e)
		{
			this.unrated = null;
		}
	}
	
	/**
	 * @return Erfahrungswert
	 */
	public Float getExperienceValue()
	{
		return experienceValue;
	}
	
	protected void setExperienceValue(Float experienceValue)
	{
		this.experienceValue = experienceValue;
	}
	
	protected void setExperienceValue(String experienceValue)
	{
		try
		{
			this.experienceValue = Float.parseFloat(experienceValue);
		}
		catch (Exception e)
		{
			this.experienceValue = null;
		}
	}
	
	/**
	 * @return DWZ des Gegners
	 */
	public Integer getOpponentDwz()
	{
		return opponentDwz;
	}
	
	protected void setOpponentDwz(Integer opponentDwz)
	{
		this.opponentDwz = opponentDwz;
	}
	
	protected void setOpponentDwz(String opponentDwz)
	{
		try
		{
			this.opponentDwz = Integer.parseInt(opponentDwz);
		}
		catch (Exception e)
		{
			this.opponentDwz = null;
		}
	}
	
	/**
	 * @return Koeffizient
	 */
	public Integer getCoefficient()
	{
		return coefficient;
	}
	
	protected void setCoefficient(Integer coefficient)
	{
		this.coefficient = coefficient;
	}
	
	protected void setCoefficient(String coefficient)
	{
		try
		{
			this.coefficient = Integer.parseInt(coefficient);
		}
		catch (Exception e)
		{
			this.coefficient = null;
		}
	}
	
	/**
	 * @return Neue DWZ
	 */
	public Integer getNewDwz()
	{
		return newDwz;
	}
	
	protected void setNewDwz(Integer newDwz)
	{
		this.newDwz = newDwz;
	}
	
	protected void setNewDwz(String newDwz)
	{
		try
		{
			this.newDwz = Integer.parseInt(newDwz);
		}
		catch (Exception e)
		{
			this.newDwz = null;
		}
	}
	
	/**
	 * @return Neuer DWZ Index
	 */
	public Integer getNewDwzIndex()
	{
		return newDwzIndex;
	}
	
	protected void setNewDwzIndex(Integer newDwzIndex)
	{
		this.newDwzIndex = newDwzIndex;
	}
	
	protected void setNewDwzIndex(String newDwzIndex)
	{
		try
		{
			this.newDwzIndex = Integer.parseInt(newDwzIndex);
		}
		catch (Exception e)
		{
			this.newDwzIndex = null;
		}
	}
	
	/**
	 * @return Performance
	 */
	public Integer getPerformance()
	{
		return performance;
	}
	
	protected void setPerformance(Integer performance)
	{
		this.performance = performance;
	}
	
	protected void setPerformance(String performance)
	{
		try
		{
			this.performance = Integer.parseInt(performance);
		}
		catch (Exception e)
		{
			this.performance = null;
		}
	}
}